@@ -1,19 +1,20 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2012-2018 Snowflake Computing Inc. All right reserved.
+# Copyright (c) 2012-2019 Snowflake Computing Inc. All right reserved.
 #
 import json
 import logging
 
-from .auth import Auth, AuthByExternalService
-from .compat import (urlsplit, unescape, urlencode)
-from .errorcode import (ER_IDP_CONNECTION_ERROR,
-                        ER_INCORRECT_DESTINATION)
-from .errors import (Error, DatabaseError)
-from .network import (CONTENT_TYPE_APPLICATION_JSON,
-                      PYTHON_CONNECTOR_USER_AGENT)
-from .sqlstate import (SQLSTATE_CONNECTION_WAS_NOT_ESTABLISHED)
+from .auth import Auth
+from .auth_by_plugin import AuthByPlugin
+from .compat import unescape, urlencode, urlsplit
+from .constants import HTTP_HEADER_ACCEPT, HTTP_HEADER_CONTENT_TYPE, \
+    HTTP_HEADER_SERVICE_NAME, HTTP_HEADER_USER_AGENT
+from .errorcode import ER_IDP_CONNECTION_ERROR, ER_INCORRECT_DESTINATION
+from .errors import DatabaseError, Error
+from .network import CONTENT_TYPE_APPLICATION_JSON, PYTHON_CONNECTOR_USER_AGENT
+from .sqlstate import SQLSTATE_CONNECTION_WAS_NOT_ESTABLISHED
 
 logger = logging.getLogger(__name__)
 
@@ -55,7 +56,7 @@ def _get_post_back_url_from_html(html):
     return unescape(html[start_idx + 8:end_idx])
 
 
-class AuthByOkta(AuthByExternalService):
+class AuthByOkta(AuthByPlugin):
     """
     Authenticate user by OKTA
     """
@@ -72,7 +73,8 @@ class AuthByOkta(AuthByExternalService):
     def update_body(self, body):
         body[u'data'][u'RAW_SAML_RESPONSE'] = self._saml_response
 
-    def authenticate(self, authenticator, account, user, password):
+    def authenticate(
+            self, authenticator, service_name, account, user, password):
         """
         SAML Authentication
         1.  query GS to obtain IDP token and SSO url
@@ -96,27 +98,34 @@ class AuthByOkta(AuthByExternalService):
             preventing a SAML assertion issued to one SP from being sent to
             another SP.
         """
-        logger.info(u'authenticating by SAML')
-        headers, sso_url, token_url = self._step1(account, user, authenticator)
+        logger.debug(u'authenticating by SAML')
+        headers, sso_url, token_url = self._step1(
+            authenticator, service_name, account, user)
         self._step2(authenticator, sso_url, token_url)
         one_time_token = self._step3(headers, token_url, user, password)
         response_html = self._step4(one_time_token, sso_url)
         self._step5(response_html)
 
-    def _step1(self, account, user, authenticator):
+    def _step1(self, authenticator, service_name, account, user):
         logger.debug(u'step 1: query GS to obtain IDP token and SSO url')
 
         headers = {
-            u'Content-Type': CONTENT_TYPE_APPLICATION_JSON,
-            u"accept": CONTENT_TYPE_APPLICATION_JSON,
-            u"User-Agent": PYTHON_CONNECTOR_USER_AGENT,
+            HTTP_HEADER_CONTENT_TYPE: CONTENT_TYPE_APPLICATION_JSON,
+            HTTP_HEADER_ACCEPT: CONTENT_TYPE_APPLICATION_JSON,
+            HTTP_HEADER_USER_AGENT: PYTHON_CONNECTOR_USER_AGENT,
         }
+        if service_name:
+            headers[HTTP_HEADER_SERVICE_NAME] = service_name
         url = u"/session/authenticator-request"
         body = Auth.base_auth_data(
             user, account,
             self._rest._connection.application,
             self._rest._connection._internal_application_name,
-            self._rest._connection._internal_application_version)
+            self._rest._connection._internal_application_version,
+            self._rest._connection._ocsp_mode(),
+            self._rest._connection._login_timeout,
+            self._rest._connection._network_timeout,
+        )
 
         body[u"data"][u"AUTHENTICATOR"] = authenticator
         logger.debug(
@@ -125,8 +134,8 @@ class AuthByOkta(AuthByExternalService):
         )
         ret = self._rest._post_request(
             url, headers, json.dumps(body),
-            timeout=self._rest._connection._login_timeout,
-            socket_timeout=self._rest._connection._login_timeout)
+            timeout=self._rest._connection.login_timeout,
+            socket_timeout=self._rest._connection.login_timeout)
 
         if not ret[u'success']:
             self.handle_failure(ret)
@@ -166,8 +175,8 @@ class AuthByOkta(AuthByExternalService):
         ret = self._rest.fetch(
             u'post', token_url, headers,
             data=json.dumps(data),
-            timeout=self._rest._connection._login_timeout,
-            socket_timeout=self._rest._connection._login_timeout,
+            timeout=self._rest._connection.login_timeout,
+            socket_timeout=self._rest._connection.login_timeout,
             catch_okta_unauthorized_error=True)
         one_time_token = ret.get(u'cookieToken')
         if not one_time_token:
@@ -194,12 +203,12 @@ class AuthByOkta(AuthByExternalService):
         }
         sso_url = sso_url + u'?' + urlencode(url_parameters)
         headers = {
-            u"Accept": u'*/*',
+            HTTP_HEADER_ACCEPT: u'*/*',
         }
         response_html = self._rest.fetch(
             u'get', sso_url, headers,
-            timeout=self._rest._connection._login_timeout,
-            socket_timeout=self._rest._connection._login_timeout,
+            timeout=self._rest._connection.login_timeout,
+            socket_timeout=self._rest._connection.login_timeout,
             is_raw_text=True)
         return response_html
 
