@@ -11,12 +11,10 @@ from logging import getLogger
 
 import pytz
 
-from .compat import (PY2, IS_BINARY, TO_UNICODE, IS_NUMERIC)
-from .errorcode import (
-    ER_NOT_SUPPORT_DATA_TYPE)
-from .errors import (ProgrammingError)
-from .sfbinaryformat import (binary_to_python,
-                             binary_to_snowflake)
+from .compat import IS_BINARY, TO_UNICODE, IS_NUMERIC
+from .errorcode import ER_NOT_SUPPORT_DATA_TYPE
+from .errors import ProgrammingError
+from .sfbinaryformat import binary_to_python, binary_to_snowflake
 from .sfdatetime import sfdatetime_total_seconds_from_timedelta
 
 try:
@@ -116,7 +114,7 @@ def _adjust_fraction_of_nanoseconds(value, max_fraction, scale):
     if scale == 0:
         return 0
     if value[0] != '-':
-        return int((value[-scale:] + ZERO_FILL[:9 - scale]))
+        return int(value[-scale:] + ZERO_FILL[:9 - scale])
 
     frac = int(value[-scale:])
     if frac == 0:
@@ -262,10 +260,7 @@ class SnowflakeConverter(object):
             if tzlocal is not None:
                 return tzlocal.get_localzone()
             else:
-                try:
-                    return datetime.timezone.utc
-                except AttributeError:  # py2k
-                    return pytz.timezone('UTC')
+                return datetime.timezone.utc
 
     def _pre_TIMESTAMP_LTZ_to_python(self, value, ctx):
         """
@@ -624,17 +619,17 @@ class SnowflakeConverter(object):
     def __getattr__(self, item):
         if item.endswith('_to_snowflake'):
             raise ProgrammingError(
-                msg=u"Binding data in type ({0}) is not supported.".format(
+                msg=u"Binding data in type ({}) is not supported.".format(
                     item[1:item.find('_to_snowflake')]),
                 errno=ER_NOT_SUPPORT_DATA_TYPE
             )
         elif item.endswith('to_snowflake_bindings'):
             raise ProgrammingError(
-                msg=u"Binding data in type ({0}) is not supported.".format(
+                msg=u"Binding data in type ({}) is not supported.".format(
                     item[1:item.find('_to_snowflake_bindings')]),
                 errno=ER_NOT_SUPPORT_DATA_TYPE
             )
-        raise AttributeError('No method is available: {0}'.format(item))
+        raise AttributeError('No method is available: {}'.format(item))
 
     @staticmethod
     def escape(value):
@@ -657,12 +652,10 @@ class SnowflakeConverter(object):
             return u'NULL'
         elif isinstance(value, bool):
             return u'TRUE' if value else u'FALSE'
-        elif PY2 and isinstance(value, long):
-            return TO_UNICODE(str(value))
         elif IS_NUMERIC(value):
             return TO_UNICODE(repr(value))
         elif IS_BINARY(value):
             # Binary literal syntax
-            return u"X'{0}'".format(value.decode('ascii'))
+            return u"X'{}'".format(value.decode('ascii'))
 
-        return u"'{0}'".format(value)
+        return u"'{}'".format(value)
